/// <reference types="node" />
import { ChannelCredentials, ChannelOptions, UntypedServiceImplementation, handleUnaryCall, Client, ClientUnaryCall, Metadata, CallOptions, ServiceError } from "@grpc/grpc-js";
import _m0 from "protobufjs/minimal";
import { SignedBatchVAAWithQuorum, Heartbeat } from "../../gossip/v1/gossip";
export declare const protobufPackage = "publicrpc.v1";
export declare enum ChainID {
    CHAIN_ID_UNSPECIFIED = 0,
    CHAIN_ID_SOLANA = 1,
    CHAIN_ID_ETHEREUM = 2,
    CHAIN_ID_TERRA = 3,
    CHAIN_ID_BSC = 4,
    CHAIN_ID_POLYGON = 5,
    CHAIN_ID_AVALANCHE = 6,
    CHAIN_ID_OASIS = 7,
    CHAIN_ID_ALGORAND = 8,
    CHAIN_ID_AURORA = 9,
    CHAIN_ID_FANTOM = 10,
    CHAIN_ID_KARURA = 11,
    CHAIN_ID_ACALA = 12,
    CHAIN_ID_KLAYTN = 13,
    CHAIN_ID_CELO = 14,
    CHAIN_ID_NEAR = 15,
    CHAIN_ID_MOONBEAM = 16,
    CHAIN_ID_NEON = 17,
    CHAIN_ID_TERRA2 = 18,
    CHAIN_ID_INJECTIVE = 19,
    CHAIN_ID_OSMOSIS = 20,
    CHAIN_ID_SUI = 21,
    CHAIN_ID_APTOS = 22,
    CHAIN_ID_ARBITRUM = 23,
    CHAIN_ID_OPTIMISM = 24,
    CHAIN_ID_GNOSIS = 25,
    CHAIN_ID_PYTHNET = 26,
    CHAIN_ID_XPLA = 28,
    UNRECOGNIZED = -1
}
export declare function chainIDFromJSON(object: any): ChainID;
export declare function chainIDToJSON(object: ChainID): string;
/** MessageID is a VAA's globally unique identifier (see data availability design document). */
export interface MessageID {
    /** Emitter chain ID. */
    emitterChain: ChainID;
    /** Hex-encoded (without leading 0x) emitter address. */
    emitterAddress: string;
    /** Sequence number for (emitter_chain, emitter_address). */
    sequence: string;
}
export interface BatchID {
    /** Emitter chain ID. */
    emitterChain: ChainID;
    /** Transaction's unique identifier. */
    txId: Buffer;
    /** Nonce of the messages in the batch. */
    nonce: number;
}
export interface GetSignedVAARequest {
    messageId: MessageID | undefined;
}
export interface GetSignedVAAResponse {
    vaaBytes: Buffer;
}
export interface GetSignedBatchVAARequest {
    batchId: BatchID | undefined;
}
export interface GetSignedBatchVAAResponse {
    signedBatchVaa: SignedBatchVAAWithQuorum | undefined;
}
export interface GetLastHeartbeatsRequest {
}
export interface GetLastHeartbeatsResponse {
    entries: GetLastHeartbeatsResponse_Entry[];
}
export interface GetLastHeartbeatsResponse_Entry {
    /**
     * Verified, hex-encoded (with leading 0x) guardian address. This is the guardian address
     * which signed this heartbeat. The GuardianAddr field inside the heartbeat
     * is NOT verified - remote nodes can put arbitrary data in it.
     */
    verifiedGuardianAddr: string;
    /**
     * Base58-encoded libp2p node address that sent this heartbeat, used to
     * distinguish between multiple nodes running for the same guardian.
     */
    p2pNodeAddr: string;
    /**
     * Raw heartbeat received from the network. Data is only as trusted
     * as the guardian node that sent it - none of the fields are verified.
     */
    rawHeartbeat: Heartbeat | undefined;
}
export interface GetCurrentGuardianSetRequest {
}
export interface GetCurrentGuardianSetResponse {
    guardianSet: GuardianSet | undefined;
}
export interface GuardianSet {
    /** Guardian set index */
    index: number;
    /** List of guardian addresses as human-readable hex-encoded (leading 0x) addresses. */
    addresses: string[];
}
export interface GovernorGetAvailableNotionalByChainRequest {
}
export interface GovernorGetAvailableNotionalByChainResponse {
    /**
     * There is an entry for each chain that is being governed.
     * Chains that are not being governed are not listed, and assumed to be unlimited.
     */
    entries: GovernorGetAvailableNotionalByChainResponse_Entry[];
}
export interface GovernorGetAvailableNotionalByChainResponse_Entry {
    chainId: number;
    remainingAvailableNotional: string;
    notionalLimit: string;
    bigTransactionSize: string;
}
export interface GovernorGetEnqueuedVAAsRequest {
}
export interface GovernorGetEnqueuedVAAsResponse {
    /** There is an entry for each enqueued vaa. */
    entries: GovernorGetEnqueuedVAAsResponse_Entry[];
}
export interface GovernorGetEnqueuedVAAsResponse_Entry {
    emitterChain: number;
    /** human-readable hex-encoded (leading 0x) */
    emitterAddress: string;
    sequence: string;
    releaseTime: number;
    notionalValue: string;
    txHash: string;
}
export interface GovernorIsVAAEnqueuedRequest {
    messageId: MessageID | undefined;
}
export interface GovernorIsVAAEnqueuedResponse {
    isEnqueued: boolean;
}
export interface GovernorGetTokenListRequest {
}
export interface GovernorGetTokenListResponse {
    /** There is an entry for each token that applies to the notional TVL calcuation. */
    entries: GovernorGetTokenListResponse_Entry[];
}
export interface GovernorGetTokenListResponse_Entry {
    originChainId: number;
    /** human-readable hex-encoded (leading 0x) */
    originAddress: string;
    price: number;
}
export declare const MessageID: {
    encode(message: MessageID, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): MessageID;
    fromJSON(object: any): MessageID;
    toJSON(message: MessageID): unknown;
    fromPartial(object: DeepPartial<MessageID>): MessageID;
};
export declare const BatchID: {
    encode(message: BatchID, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): BatchID;
    fromJSON(object: any): BatchID;
    toJSON(message: BatchID): unknown;
    fromPartial(object: DeepPartial<BatchID>): BatchID;
};
export declare const GetSignedVAARequest: {
    encode(message: GetSignedVAARequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): GetSignedVAARequest;
    fromJSON(object: any): GetSignedVAARequest;
    toJSON(message: GetSignedVAARequest): unknown;
    fromPartial(object: DeepPartial<GetSignedVAARequest>): GetSignedVAARequest;
};
export declare const GetSignedVAAResponse: {
    encode(message: GetSignedVAAResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): GetSignedVAAResponse;
    fromJSON(object: any): GetSignedVAAResponse;
    toJSON(message: GetSignedVAAResponse): unknown;
    fromPartial(object: DeepPartial<GetSignedVAAResponse>): GetSignedVAAResponse;
};
export declare const GetSignedBatchVAARequest: {
    encode(message: GetSignedBatchVAARequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): GetSignedBatchVAARequest;
    fromJSON(object: any): GetSignedBatchVAARequest;
    toJSON(message: GetSignedBatchVAARequest): unknown;
    fromPartial(object: DeepPartial<GetSignedBatchVAARequest>): GetSignedBatchVAARequest;
};
export declare const GetSignedBatchVAAResponse: {
    encode(message: GetSignedBatchVAAResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): GetSignedBatchVAAResponse;
    fromJSON(object: any): GetSignedBatchVAAResponse;
    toJSON(message: GetSignedBatchVAAResponse): unknown;
    fromPartial(object: DeepPartial<GetSignedBatchVAAResponse>): GetSignedBatchVAAResponse;
};
export declare const GetLastHeartbeatsRequest: {
    encode(_: GetLastHeartbeatsRequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): GetLastHeartbeatsRequest;
    fromJSON(_: any): GetLastHeartbeatsRequest;
    toJSON(_: GetLastHeartbeatsRequest): unknown;
    fromPartial(_: DeepPartial<GetLastHeartbeatsRequest>): GetLastHeartbeatsRequest;
};
export declare const GetLastHeartbeatsResponse: {
    encode(message: GetLastHeartbeatsResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): GetLastHeartbeatsResponse;
    fromJSON(object: any): GetLastHeartbeatsResponse;
    toJSON(message: GetLastHeartbeatsResponse): unknown;
    fromPartial(object: DeepPartial<GetLastHeartbeatsResponse>): GetLastHeartbeatsResponse;
};
export declare const GetLastHeartbeatsResponse_Entry: {
    encode(message: GetLastHeartbeatsResponse_Entry, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): GetLastHeartbeatsResponse_Entry;
    fromJSON(object: any): GetLastHeartbeatsResponse_Entry;
    toJSON(message: GetLastHeartbeatsResponse_Entry): unknown;
    fromPartial(object: DeepPartial<GetLastHeartbeatsResponse_Entry>): GetLastHeartbeatsResponse_Entry;
};
export declare const GetCurrentGuardianSetRequest: {
    encode(_: GetCurrentGuardianSetRequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): GetCurrentGuardianSetRequest;
    fromJSON(_: any): GetCurrentGuardianSetRequest;
    toJSON(_: GetCurrentGuardianSetRequest): unknown;
    fromPartial(_: DeepPartial<GetCurrentGuardianSetRequest>): GetCurrentGuardianSetRequest;
};
export declare const GetCurrentGuardianSetResponse: {
    encode(message: GetCurrentGuardianSetResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): GetCurrentGuardianSetResponse;
    fromJSON(object: any): GetCurrentGuardianSetResponse;
    toJSON(message: GetCurrentGuardianSetResponse): unknown;
    fromPartial(object: DeepPartial<GetCurrentGuardianSetResponse>): GetCurrentGuardianSetResponse;
};
export declare const GuardianSet: {
    encode(message: GuardianSet, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): GuardianSet;
    fromJSON(object: any): GuardianSet;
    toJSON(message: GuardianSet): unknown;
    fromPartial(object: DeepPartial<GuardianSet>): GuardianSet;
};
export declare const GovernorGetAvailableNotionalByChainRequest: {
    encode(_: GovernorGetAvailableNotionalByChainRequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): GovernorGetAvailableNotionalByChainRequest;
    fromJSON(_: any): GovernorGetAvailableNotionalByChainRequest;
    toJSON(_: GovernorGetAvailableNotionalByChainRequest): unknown;
    fromPartial(_: DeepPartial<GovernorGetAvailableNotionalByChainRequest>): GovernorGetAvailableNotionalByChainRequest;
};
export declare const GovernorGetAvailableNotionalByChainResponse: {
    encode(message: GovernorGetAvailableNotionalByChainResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): GovernorGetAvailableNotionalByChainResponse;
    fromJSON(object: any): GovernorGetAvailableNotionalByChainResponse;
    toJSON(message: GovernorGetAvailableNotionalByChainResponse): unknown;
    fromPartial(object: DeepPartial<GovernorGetAvailableNotionalByChainResponse>): GovernorGetAvailableNotionalByChainResponse;
};
export declare const GovernorGetAvailableNotionalByChainResponse_Entry: {
    encode(message: GovernorGetAvailableNotionalByChainResponse_Entry, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): GovernorGetAvailableNotionalByChainResponse_Entry;
    fromJSON(object: any): GovernorGetAvailableNotionalByChainResponse_Entry;
    toJSON(message: GovernorGetAvailableNotionalByChainResponse_Entry): unknown;
    fromPartial(object: DeepPartial<GovernorGetAvailableNotionalByChainResponse_Entry>): GovernorGetAvailableNotionalByChainResponse_Entry;
};
export declare const GovernorGetEnqueuedVAAsRequest: {
    encode(_: GovernorGetEnqueuedVAAsRequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): GovernorGetEnqueuedVAAsRequest;
    fromJSON(_: any): GovernorGetEnqueuedVAAsRequest;
    toJSON(_: GovernorGetEnqueuedVAAsRequest): unknown;
    fromPartial(_: DeepPartial<GovernorGetEnqueuedVAAsRequest>): GovernorGetEnqueuedVAAsRequest;
};
export declare const GovernorGetEnqueuedVAAsResponse: {
    encode(message: GovernorGetEnqueuedVAAsResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): GovernorGetEnqueuedVAAsResponse;
    fromJSON(object: any): GovernorGetEnqueuedVAAsResponse;
    toJSON(message: GovernorGetEnqueuedVAAsResponse): unknown;
    fromPartial(object: DeepPartial<GovernorGetEnqueuedVAAsResponse>): GovernorGetEnqueuedVAAsResponse;
};
export declare const GovernorGetEnqueuedVAAsResponse_Entry: {
    encode(message: GovernorGetEnqueuedVAAsResponse_Entry, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): GovernorGetEnqueuedVAAsResponse_Entry;
    fromJSON(object: any): GovernorGetEnqueuedVAAsResponse_Entry;
    toJSON(message: GovernorGetEnqueuedVAAsResponse_Entry): unknown;
    fromPartial(object: DeepPartial<GovernorGetEnqueuedVAAsResponse_Entry>): GovernorGetEnqueuedVAAsResponse_Entry;
};
export declare const GovernorIsVAAEnqueuedRequest: {
    encode(message: GovernorIsVAAEnqueuedRequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): GovernorIsVAAEnqueuedRequest;
    fromJSON(object: any): GovernorIsVAAEnqueuedRequest;
    toJSON(message: GovernorIsVAAEnqueuedRequest): unknown;
    fromPartial(object: DeepPartial<GovernorIsVAAEnqueuedRequest>): GovernorIsVAAEnqueuedRequest;
};
export declare const GovernorIsVAAEnqueuedResponse: {
    encode(message: GovernorIsVAAEnqueuedResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): GovernorIsVAAEnqueuedResponse;
    fromJSON(object: any): GovernorIsVAAEnqueuedResponse;
    toJSON(message: GovernorIsVAAEnqueuedResponse): unknown;
    fromPartial(object: DeepPartial<GovernorIsVAAEnqueuedResponse>): GovernorIsVAAEnqueuedResponse;
};
export declare const GovernorGetTokenListRequest: {
    encode(_: GovernorGetTokenListRequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): GovernorGetTokenListRequest;
    fromJSON(_: any): GovernorGetTokenListRequest;
    toJSON(_: GovernorGetTokenListRequest): unknown;
    fromPartial(_: DeepPartial<GovernorGetTokenListRequest>): GovernorGetTokenListRequest;
};
export declare const GovernorGetTokenListResponse: {
    encode(message: GovernorGetTokenListResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): GovernorGetTokenListResponse;
    fromJSON(object: any): GovernorGetTokenListResponse;
    toJSON(message: GovernorGetTokenListResponse): unknown;
    fromPartial(object: DeepPartial<GovernorGetTokenListResponse>): GovernorGetTokenListResponse;
};
export declare const GovernorGetTokenListResponse_Entry: {
    encode(message: GovernorGetTokenListResponse_Entry, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): GovernorGetTokenListResponse_Entry;
    fromJSON(object: any): GovernorGetTokenListResponse_Entry;
    toJSON(message: GovernorGetTokenListResponse_Entry): unknown;
    fromPartial(object: DeepPartial<GovernorGetTokenListResponse_Entry>): GovernorGetTokenListResponse_Entry;
};
/** PublicRPCService service exposes endpoints to be consumed externally; GUIs, historical record keeping, etc. */
export declare const PublicRPCServiceService: {
    /**
     * GetLastHeartbeats returns the last heartbeat received for each guardian node in the
     * node's active guardian set. Heartbeats received by nodes not in the guardian set are ignored.
     * The heartbeat value is null if no heartbeat has yet been received.
     */
    readonly getLastHeartbeats: {
        readonly path: "/publicrpc.v1.PublicRPCService/GetLastHeartbeats";
        readonly requestStream: false;
        readonly responseStream: false;
        readonly requestSerialize: (value: GetLastHeartbeatsRequest) => Buffer;
        readonly requestDeserialize: (value: Buffer) => GetLastHeartbeatsRequest;
        readonly responseSerialize: (value: GetLastHeartbeatsResponse) => Buffer;
        readonly responseDeserialize: (value: Buffer) => GetLastHeartbeatsResponse;
    };
    readonly getSignedVAA: {
        readonly path: "/publicrpc.v1.PublicRPCService/GetSignedVAA";
        readonly requestStream: false;
        readonly responseStream: false;
        readonly requestSerialize: (value: GetSignedVAARequest) => Buffer;
        readonly requestDeserialize: (value: Buffer) => GetSignedVAARequest;
        readonly responseSerialize: (value: GetSignedVAAResponse) => Buffer;
        readonly responseDeserialize: (value: Buffer) => GetSignedVAAResponse;
    };
    readonly getSignedBatchVAA: {
        readonly path: "/publicrpc.v1.PublicRPCService/GetSignedBatchVAA";
        readonly requestStream: false;
        readonly responseStream: false;
        readonly requestSerialize: (value: GetSignedBatchVAARequest) => Buffer;
        readonly requestDeserialize: (value: Buffer) => GetSignedBatchVAARequest;
        readonly responseSerialize: (value: GetSignedBatchVAAResponse) => Buffer;
        readonly responseDeserialize: (value: Buffer) => GetSignedBatchVAAResponse;
    };
    readonly getCurrentGuardianSet: {
        readonly path: "/publicrpc.v1.PublicRPCService/GetCurrentGuardianSet";
        readonly requestStream: false;
        readonly responseStream: false;
        readonly requestSerialize: (value: GetCurrentGuardianSetRequest) => Buffer;
        readonly requestDeserialize: (value: Buffer) => GetCurrentGuardianSetRequest;
        readonly responseSerialize: (value: GetCurrentGuardianSetResponse) => Buffer;
        readonly responseDeserialize: (value: Buffer) => GetCurrentGuardianSetResponse;
    };
    readonly governorGetAvailableNotionalByChain: {
        readonly path: "/publicrpc.v1.PublicRPCService/GovernorGetAvailableNotionalByChain";
        readonly requestStream: false;
        readonly responseStream: false;
        readonly requestSerialize: (value: GovernorGetAvailableNotionalByChainRequest) => Buffer;
        readonly requestDeserialize: (value: Buffer) => GovernorGetAvailableNotionalByChainRequest;
        readonly responseSerialize: (value: GovernorGetAvailableNotionalByChainResponse) => Buffer;
        readonly responseDeserialize: (value: Buffer) => GovernorGetAvailableNotionalByChainResponse;
    };
    readonly governorGetEnqueuedVAAs: {
        readonly path: "/publicrpc.v1.PublicRPCService/GovernorGetEnqueuedVAAs";
        readonly requestStream: false;
        readonly responseStream: false;
        readonly requestSerialize: (value: GovernorGetEnqueuedVAAsRequest) => Buffer;
        readonly requestDeserialize: (value: Buffer) => GovernorGetEnqueuedVAAsRequest;
        readonly responseSerialize: (value: GovernorGetEnqueuedVAAsResponse) => Buffer;
        readonly responseDeserialize: (value: Buffer) => GovernorGetEnqueuedVAAsResponse;
    };
    readonly governorIsVAAEnqueued: {
        readonly path: "/publicrpc.v1.PublicRPCService/GovernorIsVAAEnqueued";
        readonly requestStream: false;
        readonly responseStream: false;
        readonly requestSerialize: (value: GovernorIsVAAEnqueuedRequest) => Buffer;
        readonly requestDeserialize: (value: Buffer) => GovernorIsVAAEnqueuedRequest;
        readonly responseSerialize: (value: GovernorIsVAAEnqueuedResponse) => Buffer;
        readonly responseDeserialize: (value: Buffer) => GovernorIsVAAEnqueuedResponse;
    };
    readonly governorGetTokenList: {
        readonly path: "/publicrpc.v1.PublicRPCService/GovernorGetTokenList";
        readonly requestStream: false;
        readonly responseStream: false;
        readonly requestSerialize: (value: GovernorGetTokenListRequest) => Buffer;
        readonly requestDeserialize: (value: Buffer) => GovernorGetTokenListRequest;
        readonly responseSerialize: (value: GovernorGetTokenListResponse) => Buffer;
        readonly responseDeserialize: (value: Buffer) => GovernorGetTokenListResponse;
    };
};
export interface PublicRPCServiceServer extends UntypedServiceImplementation {
    /**
     * GetLastHeartbeats returns the last heartbeat received for each guardian node in the
     * node's active guardian set. Heartbeats received by nodes not in the guardian set are ignored.
     * The heartbeat value is null if no heartbeat has yet been received.
     */
    getLastHeartbeats: handleUnaryCall<GetLastHeartbeatsRequest, GetLastHeartbeatsResponse>;
    getSignedVAA: handleUnaryCall<GetSignedVAARequest, GetSignedVAAResponse>;
    getSignedBatchVAA: handleUnaryCall<GetSignedBatchVAARequest, GetSignedBatchVAAResponse>;
    getCurrentGuardianSet: handleUnaryCall<GetCurrentGuardianSetRequest, GetCurrentGuardianSetResponse>;
    governorGetAvailableNotionalByChain: handleUnaryCall<GovernorGetAvailableNotionalByChainRequest, GovernorGetAvailableNotionalByChainResponse>;
    governorGetEnqueuedVAAs: handleUnaryCall<GovernorGetEnqueuedVAAsRequest, GovernorGetEnqueuedVAAsResponse>;
    governorIsVAAEnqueued: handleUnaryCall<GovernorIsVAAEnqueuedRequest, GovernorIsVAAEnqueuedResponse>;
    governorGetTokenList: handleUnaryCall<GovernorGetTokenListRequest, GovernorGetTokenListResponse>;
}
export interface PublicRPCServiceClient extends Client {
    /**
     * GetLastHeartbeats returns the last heartbeat received for each guardian node in the
     * node's active guardian set. Heartbeats received by nodes not in the guardian set are ignored.
     * The heartbeat value is null if no heartbeat has yet been received.
     */
    getLastHeartbeats(request: GetLastHeartbeatsRequest, callback: (error: ServiceError | null, response: GetLastHeartbeatsResponse) => void): ClientUnaryCall;
    getLastHeartbeats(request: GetLastHeartbeatsRequest, metadata: Metadata, callback: (error: ServiceError | null, response: GetLastHeartbeatsResponse) => void): ClientUnaryCall;
    getLastHeartbeats(request: GetLastHeartbeatsRequest, metadata: Metadata, options: Partial<CallOptions>, callback: (error: ServiceError | null, response: GetLastHeartbeatsResponse) => void): ClientUnaryCall;
    getSignedVAA(request: GetSignedVAARequest, callback: (error: ServiceError | null, response: GetSignedVAAResponse) => void): ClientUnaryCall;
    getSignedVAA(request: GetSignedVAARequest, metadata: Metadata, callback: (error: ServiceError | null, response: GetSignedVAAResponse) => void): ClientUnaryCall;
    getSignedVAA(request: GetSignedVAARequest, metadata: Metadata, options: Partial<CallOptions>, callback: (error: ServiceError | null, response: GetSignedVAAResponse) => void): ClientUnaryCall;
    getSignedBatchVAA(request: GetSignedBatchVAARequest, callback: (error: ServiceError | null, response: GetSignedBatchVAAResponse) => void): ClientUnaryCall;
    getSignedBatchVAA(request: GetSignedBatchVAARequest, metadata: Metadata, callback: (error: ServiceError | null, response: GetSignedBatchVAAResponse) => void): ClientUnaryCall;
    getSignedBatchVAA(request: GetSignedBatchVAARequest, metadata: Metadata, options: Partial<CallOptions>, callback: (error: ServiceError | null, response: GetSignedBatchVAAResponse) => void): ClientUnaryCall;
    getCurrentGuardianSet(request: GetCurrentGuardianSetRequest, callback: (error: ServiceError | null, response: GetCurrentGuardianSetResponse) => void): ClientUnaryCall;
    getCurrentGuardianSet(request: GetCurrentGuardianSetRequest, metadata: Metadata, callback: (error: ServiceError | null, response: GetCurrentGuardianSetResponse) => void): ClientUnaryCall;
    getCurrentGuardianSet(request: GetCurrentGuardianSetRequest, metadata: Metadata, options: Partial<CallOptions>, callback: (error: ServiceError | null, response: GetCurrentGuardianSetResponse) => void): ClientUnaryCall;
    governorGetAvailableNotionalByChain(request: GovernorGetAvailableNotionalByChainRequest, callback: (error: ServiceError | null, response: GovernorGetAvailableNotionalByChainResponse) => void): ClientUnaryCall;
    governorGetAvailableNotionalByChain(request: GovernorGetAvailableNotionalByChainRequest, metadata: Metadata, callback: (error: ServiceError | null, response: GovernorGetAvailableNotionalByChainResponse) => void): ClientUnaryCall;
    governorGetAvailableNotionalByChain(request: GovernorGetAvailableNotionalByChainRequest, metadata: Metadata, options: Partial<CallOptions>, callback: (error: ServiceError | null, response: GovernorGetAvailableNotionalByChainResponse) => void): ClientUnaryCall;
    governorGetEnqueuedVAAs(request: GovernorGetEnqueuedVAAsRequest, callback: (error: ServiceError | null, response: GovernorGetEnqueuedVAAsResponse) => void): ClientUnaryCall;
    governorGetEnqueuedVAAs(request: GovernorGetEnqueuedVAAsRequest, metadata: Metadata, callback: (error: ServiceError | null, response: GovernorGetEnqueuedVAAsResponse) => void): ClientUnaryCall;
    governorGetEnqueuedVAAs(request: GovernorGetEnqueuedVAAsRequest, metadata: Metadata, options: Partial<CallOptions>, callback: (error: ServiceError | null, response: GovernorGetEnqueuedVAAsResponse) => void): ClientUnaryCall;
    governorIsVAAEnqueued(request: GovernorIsVAAEnqueuedRequest, callback: (error: ServiceError | null, response: GovernorIsVAAEnqueuedResponse) => void): ClientUnaryCall;
    governorIsVAAEnqueued(request: GovernorIsVAAEnqueuedRequest, metadata: Metadata, callback: (error: ServiceError | null, response: GovernorIsVAAEnqueuedResponse) => void): ClientUnaryCall;
    governorIsVAAEnqueued(request: GovernorIsVAAEnqueuedRequest, metadata: Metadata, options: Partial<CallOptions>, callback: (error: ServiceError | null, response: GovernorIsVAAEnqueuedResponse) => void): ClientUnaryCall;
    governorGetTokenList(request: GovernorGetTokenListRequest, callback: (error: ServiceError | null, response: GovernorGetTokenListResponse) => void): ClientUnaryCall;
    governorGetTokenList(request: GovernorGetTokenListRequest, metadata: Metadata, callback: (error: ServiceError | null, response: GovernorGetTokenListResponse) => void): ClientUnaryCall;
    governorGetTokenList(request: GovernorGetTokenListRequest, metadata: Metadata, options: Partial<CallOptions>, callback: (error: ServiceError | null, response: GovernorGetTokenListResponse) => void): ClientUnaryCall;
}
export declare const PublicRPCServiceClient: new (address: string, credentials: ChannelCredentials, options?: Partial<ChannelOptions>) => PublicRPCServiceClient;
declare type Builtin = Date | Function | Uint8Array | string | number | boolean | undefined;
export declare type DeepPartial<T> = T extends Builtin ? T : T extends Array<infer U> ? Array<DeepPartial<U>> : T extends ReadonlyArray<infer U> ? ReadonlyArray<DeepPartial<U>> : T extends {} ? {
    [K in keyof T]?: DeepPartial<T[K]>;
} : Partial<T>;
export {};
